hist — biskit 3.0.0a1 documentation

# hist

create a histogram from data

Functions Overview

`density` | returns the normalized histogram of x:: density( data, nBins [,range=None, steps=1, hist=0|1] ) -> array
`histogram` | Create a histogram.

Classes Overview

## hist Module Details

`biskit.hist.` `histogram`(data, nbins, range=None)

  Create a histogram. Comes from Konrad Hinsen: Scientific Python

  Parameters: | data ([any]) – data list or array nbins (int) – number of bins range ((float, float) OR None) – data range to create histogram from (min val, max val)
  Returns: | array (2 x len(data) ) with start of bin and witdh of bin.
  Return type: | array

`biskit.hist.` `density`(x, nBins, range=None, steps=1, hist=0)
  returns the normalized histogram of x::
    density( data, nBins [,range=None, steps=1, hist=0|1] ) -> array

  Parameters: | x ([any]) – data list or array nBins (int) – number of bins range ((float, float) OR None) – data range to create histogram from (min val, max val) steps (1|0) – 1: histogram appears as a discrete graph (default 1) hist (1|0) – 0: normalize histogram (default 0)
  Returns: | array (2 x len(data) ) with start of bin and witdh of bin.
  Return type: | array